@@ -4,13 +4,12 @@ use strict;
 
 use Carp;
 
-use Rose::HTML::Form::Field::Checkbox;
+use base 'Rose::HTML::Form::Field::Group::OnOff';
 
 use Rose::HTML::Form::Field::Group;
-use Rose::HTML::Form::Field::Group::OnOff;
-our @ISA = qw(Rose::HTML::Form::Field::Group::OnOff);
+use Rose::HTML::Form::Field::Checkbox;
 
-our $VERSION = '0.554';
+our $VERSION = '0.606';
 
 sub _item_class       { shift->object_type_class_loaded('checkbox') }
 sub _item_name        { 'checkbox' }
@@ -399,4 +398,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
