@@ -6,10 +6,9 @@ use Rose::DateTime::Util();
 
 use Rose::HTML::Object::Messages qw(:date);
 
-use Rose::HTML::Form::Field::DateTime::Split;
-our @ISA = qw(Rose::HTML::Form::Field::DateTime::Split);
+use base 'Rose::HTML::Form::Field::DateTime::Split';
 
-our $VERSION = '0.550';
+our $VERSION = '0.606';
 
 sub build_field
 {
@@ -131,6 +130,8 @@ if(__PACKAGE__->localizer->auto_load_messages)
   __PACKAGE__->localizer->load_all_messages;
 }
 
+use utf8; # The __DATA__ section contains UTF-8 text
+
 1;
 
 __DATA__
@@ -277,4 +278,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
