@@ -2,11 +2,9 @@ package Rose::HTML::Form::Field::Time::Split;
 
 use strict;
 
-use Rose::HTML::Form::Field::Time;
-use Rose::HTML::Form::Field::Compound;
-our @ISA = qw(Rose::HTML::Form::Field::Compound Rose::HTML::Form::Field::Time);
+use base qw(Rose::HTML::Form::Field::Compound Rose::HTML::Form::Field::Time);
 
-our $VERSION = '0.011';
+our $VERSION = '0.606';
 
 # Multiple inheritence never quite works out the way I want it to...
 Rose::HTML::Form::Field::Time->import_methods
