@@ -5,8 +5,7 @@ use strict;
 use Carp;
 use Rose::HTML::Object::Message::Localizer;
 
-use Rose::HTML::Object::Message;
-our @ISA = qw(Rose::HTML::Object::Message);
+use base 'Rose::HTML::Object::Message';
 
 our $VERSION = '0.600';
 
@@ -245,4 +244,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
